@@ -1,15 +1,17 @@
-binom_gl <-function( r, m, x, link, p, K, initval) {
+#' @importFrom stats optim
+binom_gl <-function( r, m, x, link, p, K,
+                     initval) {
 #
 # THIS IS AN INTERNAL FUNCTION: USE BINOM_LIMS FOR BEST RESULTS
 #
 # Maximum likelihood estimates of the parameters of the psychometric function
 # with guessing and lapsing rates. The estimated parameters for the
-# linear part are in vector 'b' and the estimated rates are in 'guessing' and 'lapsing'.   
+# linear part are in vector 'b' and the estimated rates are in 'guessing' and 'lapsing'.
 #
 # INPUT
 #
 # r    - number of successes at points x
-# m    - number of trials at points x 
+# m    - number of trials at points x
 # x    - stimulus levels
 # link    - name of the link function
 # p       - degree of the polynomial
@@ -17,11 +19,11 @@ binom_gl <-function( r, m, x, link, p, K, initval) {
 # initval - initial values for guessing and lapsing
 #
 # OUTPUT
-# 
-# Object with 4 components: 
+#
+# Object with 4 components:
 # b - vector of estiamted coefficients for the linear part
 # guessing - estimated guessing rate
-# lapsing - estimated lapsing rate 
+# lapsing - estimated lapsing rate
 # fit - glm object to be used in evaluation of fitted values
 
 # LIKELIHOOD
@@ -66,7 +68,7 @@ binom_gl <-function( r, m, x, link, p, K, initval) {
         }
     }
     fit <- NULL;
-    
+
 # GLM fit
 	if( link != "logit"      &&
             link != "probit"     &&
@@ -78,12 +80,12 @@ binom_gl <-function( r, m, x, link, p, K, initval) {
             	}else{
             		linkfun <- paste( link, "_link_private", sep = "" );
             		}
-           		
+
     suppressWarnings( gl <- optim( initval, likfun )$par );
 
    guessing <- 1 / ( 1 + exp( -gl[1] ) );
    lapsing <- 1 / ( 1 + exp( -gl[2] ) );
-   
+
     if( linkfun != "weibull_link_private" && linkfun != "revweibull_link_private" ) {
         tmpglm <- glm( glmformula, data = glmdata, weights = m,
                  family = binomial( eval( call( linkfun, guessing, lapsing ) ) ) );
@@ -94,16 +96,16 @@ binom_gl <-function( r, m, x, link, p, K, initval) {
     }
 
   	b <- tmpglm$coeff
-    
+
     tmpglm$df.residual <- length(x) - (p + 1) - 2
-    
+
     fit <- tmpglm
-    
+
     value <- NULL
     value$guessing <- guessing
     value$lapsing <- lapsing
     value$b <- b
     value$fit <- fit
-    
+
     return( value );
-}
\ No newline at end of file
+}
