@@ -39,7 +39,7 @@
 #' @returns  \verb{th0  }  threshold estimate
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' data("Miranda_Henson")
 #' x = Miranda_Henson$x
 #' r = Miranda_Henson$r
@@ -171,7 +171,6 @@ bootstrap_ci_th <- function( TH, r, m, x, N, h0, alpha = 0.05,
 
 # INITIAL ESTIMATE
 # initial estimates with bandiwdth h0
-options(warn=-1)
     f <- locglmfit( x, r, m, x, h0, FALSE, link, guessing, lapsing, K,
                     p, ker, maxiter, tol )$pfit;
 
@@ -209,7 +208,7 @@ options(warn=-1)
 # BOOTSTRAP ESTIMATES OF THE THRESHOLD
 
     for( i in 1:N ) {
-        ftmp <- locglmfit( X, samp[,i], m, x, h0, FALSE, link, guessing,
+        ftmp <- locglmfit_inter( X, samp[,i], m, x, h0, FALSE, link, guessing,
                            lapsing, K, p, ker, maxiter, tol )$pfit;
         th_boot[i] <- threshold_slope( ftmp, X, TH )$x_th;
      }
@@ -217,8 +216,6 @@ options(warn=-1)
     ci[1] <- quantile( th_boot, probs = alpha / 2 );
     ci[2] <- quantile( th_boot, probs = 1 - alpha / 2 );
 
-options(warn=0)
-
 	value <- NULL
     value$ci <- ci
     value$th0 <- th0
