@@ -35,7 +35,7 @@
 #' @returns  \verb{sl0  } slope estimate
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' data("Miranda_Henson")
 #' x = Miranda_Henson$x
 #' r = Miranda_Henson$r
@@ -157,9 +157,8 @@ bootstrap_sd_sl <- function( TH, r, m, x, N, h0,
     n <- length( x );
 
 # INITIAL ESTIMATE
-# initial estimates with bandiwdth h0
-options(warn=-1)
-    f <- locglmfit( x, r, m, x, h0, FALSE, link, guessing, lapsing, K,
+# initial estimates with bandwidth h0
+     f <- locglmfit( x, r, m, x, h0, FALSE, link, guessing, lapsing, K,
                     p, ker, maxiter, tol )$pfit;
 
 # dense version for estimation of the threshold
@@ -196,13 +195,11 @@ options(warn=-1)
 # BOOTSTRAP ESTIMATES OF THE THRESHOLD
 
     for( i in 1:N ) {
-        ftmp <- locglmfit( X, samp[,i], m, x, h0, FALSE, link, guessing,
+        ftmp <- locglmfit_inter( X, samp[,i], m, x, h0, FALSE, link, guessing,
                            lapsing, K, p, ker, maxiter, tol )$pfit;
         sl_boot[i] <- threshold_slope( ftmp, X, TH )$slope;
      }
 
-options(warn=0)
-
     sd <- sqrt( var(sl_boot ) );
 	value <- NULL
     value$sd <- sd
